//
//  AiBrushWorkStateModel.h
//  AiBrushBleSDK
//
//  Created by iot_user on 2019/7/9.
//  Copyright © 2019 IOT. All rights reserved.
//

#import <Foundation/Foundation.h>
#import "AiBrushBleHeader.h"

//Working status(工作状态)
typedef NS_ENUM(NSUInteger, AiBrushWorkState) {
    AiBrushWorkStateInit     = 0x00,   //Work initialization(工作初始化)
    AiBrushWorkStateStart    = 0x01,   //Work start(工作启动)
    AiBrushWorkStateEnd      = 0x02,   //End of work(工作结束)
    AiBrushWorkStateLowPower = 0x03,   //Low power, no opening(低电，禁止开启)
    AiBrushWorkStateInCharge = 0x04,   //Do not turn on during charging(充电中，禁止开启)
};
//Efforts(力度)
typedef NS_ENUM(NSUInteger, AiBrushEffortsType) {
    AiBrushEffortsTypeNormal  = 0x00, //Normal strength(力度正常)
    AiBrushEffortsTypeTooMuch = 0x01, //Too strong(力度过大)
};
//工作节点
typedef NS_ENUM(NSUInteger, AiBrushWorkNodeType) {
    AiBrushWorkNodeTypePhaseOneBegin    = 0x00, //Phase 1 start(阶段一起始)
    AiBrushWorkNodeTypePhaseTwoBegin    = 0x01, //Phase 2 start(阶段二起始)
    AiBrushWorkNodeTypePhaseThreeBegin  = 0x02, //Phase 3 start(阶段三起始)
    AiBrushWorkNodeTypePhaseFourBegin   = 0x03, //Phase 4 start(阶段四起始)
    AiBrushWorkNodeTypePhaseEnd         = 0x04, //End of phase(阶段结束)
};
NS_ASSUME_NONNULL_BEGIN

@interface AiBrushWorkStateModel : NSObject
//Working status(工作状态)
@property (nonatomic, assign) AiBrushWorkState workState;
//Brushing mode(刷牙模式)
@property (nonatomic, assign) AiBrushSupportBrushMode brushMode;
//Custom mode or frequency(自定义模式或频率)
/*
 When brushMode = AiBrushSupportBrushMode_Preset, it is represented as a custom number (1~5 corresponds to custom mode 1 - 5);
   When brushMode = AiBrushSupportBrushMode_Custom, it is expressed as frequency (1~8 files corresponding to 180HZ-320HZ);
( 当 brushMode = AiBrushSupportBrushMode_Preset 时，表示为自定义编号(1~5 对应自定义模式 1 - 5);
 当 brushMode = AiBrushSupportBrushMode_Custom 时，表示为频率(1~8 档对应 180HZ-320HZ);)
 */
@property (nonatomic, assign) Byte modeOrFrequency;
//Duty cycle (1~8 files corresponds to 30%-100%)(占空比(1~8 档对应 30%-100%))
@property (nonatomic, assign) Byte duty;
//持续时间(单位:S):0x01----60s，0x02----70s，0x03----80s，0x04----90s，0x05----100s，......，0x18----290s，0x19----300s;
@property (nonatomic, assign) Byte workTime;
//Strength type(力度)
@property (nonatomic, assign) AiBrushEffortsType effortsType;
//Working node(工作节点)
@property (nonatomic, assign) AiBrushWorkNodeType nodeType;



@end

NS_ASSUME_NONNULL_END
